==> feflow-devkit-xbc-webpack4-react-1.0.4.tgz: package/libs/webpack/webpack.base.config.js <==
const autoprefixer = require('autoprefixer');
const glob = require('glob');
const path = require('path');
const CleanWebpackPlugin = require('clean-webpack-plugin');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const CopyWebpackPlugin = require("copy-webpack-plugin");

const projectRoot = process.cwd();

// 设置多页配置
// const setMPA = () => {
//   const entry = {};
//   const htmlWebpackPlugins = [];
//   const entryFiles = glob.sync(path.join(projectRoot, './src/*/index.js'));

//   Object.keys(entryFiles)
//     .map((index) => {
//       const entryFile = entryFiles[index];

//       const match = entryFile.match(/src\/(.*)\/index\.js/);
//       const pageName = match && match[1];

//       entry[pageName] = entryFile;
//       return htmlWebpackPlugins.push(
//         new HtmlWebpackPlugin({
//           inlineSource: '.css$',
//           template: path.join(projectRoot, `./src/${pageName}/index.html`),
//           filename: `${pageName}.html`,
//           chunks: ['vendors', pageName],
//           inject: true,
//           minify: {
//             html5: true,
//             collapseWhitespace: true,
//             preserveLineBreaks: false,
//             minifyCSS: true,
//             minifyJS: true,
//             removeComments: false,
//           },
//         })
//       );
//     });

//   return {
//     entry,
//     htmlWebpackPlugins,
//   };
// };

// const { entry, htmlWebpackPlugins } = setMPA();

const entry = path.join(projectRoot, './src/index.js')

module.exports = {
  // context: path.join(projectRoot, "./"),
  entry: entry,
  output: {
    path: path.join(projectRoot, "dist"),
    filename: "static/js/[name].[hash].bundle.js"
  },

  // output: {
  //   path: path.resolve(__dirname, "../dist"),
  //   filename: "static/js/[name].[hash].bundle.js",
  //   chunkFilename: "static/js/[name].[chunkhash].bundle.js",
  //   pathinfo: false,
  //   publicPath: "/"
  // },

  // externals: {
  //   react: "React",
  //   "react-dom": "ReactDOM"
  // },
  resolveLoader: {
    // modules: ["node_modules"]
    modules: [
      path.resolve(__dirname, "../../node_modules"),
      path.join(projectRoot, "node_modules")
    ]
  },

  resolve: {
    extensions: [".ts", ".js", "jsx", ".tsx", ".json"],
    alias: {
      app: path.join(projectRoot, "./src/app.js"),
      "@": path.join(projectRoot, "./src")
    },
    mainFiles: ["index"],
    // modules: ["node_modules"],
    modules: [
      path.resolve(__dirname, "../../node_modules"),
      path.join(projectRoot, "node_modules"),
    ]
  },

  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: [
          path.join(projectRoot, "node_modules"),
          path.resolve(__dirname, "../../node_modules")
        ],
        use: [
          {
            loader: "babel-loader",
            options: {
              cacheDirectory: true,
              compact: false
            }
          }
        ]
      },
      {
        test: /\.(j|t)sx?$/,
        use: [
          {
            loader: "babel-loader"
          }
        ],
        exclude: [
          path.join(projectRoot, "node_modules"),
          path.resolve(__dirname, "../../node_modules")
        ]
        // exclude: path.resolve(__dirname, "../../node_modules")
      },
      {
        test: /\.(png|svg|jpg|gif)$/,
        use: [
          {
            loader: "url-loader",
            options: {
              limit: 10000,
              name: "static/img/[name].[hash:7].[ext]"
            }
          }
        ]
      },
      {
        test: /\.(woff|woff2|eot|ttf|otf)$/,
        use: [
          {
            loader: "url-loader",
            options: {
              limit: 10000,
              name: "static/fonts/[name].[hash:7].[ext]"
            }
          }
        ]
      },
      {
        test: /\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/,
        use: [
          {
            loader: "url-loader",
            options: {
              limit: 10000,
              name: "static/media/[name].[hash:7].[ext]"
            }
          }
        ]
      }
    ]
  },

  plugins: [
    // new MiniCssExtractPlugin({
    //   filename: "[name]_[contenthash:8].css"
    // }),
    new CleanWebpackPlugin(),
    new HtmlWebpackPlugin({
      filename: "index.html",
      template: path.join(projectRoot, "index.html")
      // inject: true,
    }),
    new CopyWebpackPlugin([
      {
        from: path.join(projectRoot, "./static"),
        to: "static",
        ignore: [".*"]
      }
    ])
  ]
  //   function errorPlugin() {
  //     this.hooks.done.tap('done', (stats) => {
  //       if (stats.compilation.errors && stats.compilation.errors.length && process.argv.indexOf('--watch') === -1) {
  //         process.exit(1);
  //       }
  //     });
  //   },
  // ].concat(htmlWebpackPlugins)
};

==> feflow-devkit-xbc-webpack4-react-1.0.6.tgz: package/libs/webpack/webpack.base.config.js <==
const autoprefixer = require('autoprefixer');
const glob = require('glob');
const path = require('path');
const CleanWebpackPlugin = require('clean-webpack-plugin');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const CopyWebpackPlugin = require("copy-webpack-plugin");

const projectRoot = process.cwd();

// 设置多页配置
// const setMPA = () => {
//   const entry = {};
//   const htmlWebpackPlugins = [];
//   const entryFiles = glob.sync(path.join(projectRoot, './src/*/index.js'));

//   Object.keys(entryFiles)
//     .map((index) => {
//       const entryFile = entryFiles[index];

//       const match = entryFile.match(/src\/(.*)\/index\.js/);
//       const pageName = match && match[1];

//       entry[pageName] = entryFile;
//       return htmlWebpackPlugins.push(
//         new HtmlWebpackPlugin({
//           inlineSource: '.css$',
//           template: path.join(projectRoot, `./src/${pageName}/index.html`),
//           filename: `${pageName}.html`,
//           chunks: ['vendors', pageName],
//           inject: true,
//           minify: {
//             html5: true,
//             collapseWhitespace: true,
//             preserveLineBreaks: false,
//             minifyCSS: true,
//             minifyJS: true,
//             removeComments: false,
//           },
//         })
//       );
//     });

//   return {
//     entry,
//     htmlWebpackPlugins,
//   };
// };

// const { entry, htmlWebpackPlugins } = setMPA();

const entry = path.join(projectRoot, './src/index.js')

module.exports = {
  // context: path.join(projectRoot, "./"),
  entry: entry,
  output: {
    path: path.join(projectRoot, "dist"),
    filename: "static/js/[name].[hash].bundle.js",
    chunkFilename: "static/js/[name].[chunkhash].bundle.js",
    pathinfo: false,
    publicPath: "/"
  },

  // output: {
  //   path: path.resolve(__dirname, "../dist"),
  //   filename: "static/js/[name].[hash].bundle.js",
  //   chunkFilename: "static/js/[name].[chunkhash].bundle.js",
  //   pathinfo: false,
  //   publicPath: "/"
  // },

  // externals: {
  //   react: "React",
  //   "react-dom": "ReactDOM"
  // },
  resolveLoader: {
    // modules: ["node_modules"]
    modules: [
      path.resolve(__dirname, "../../node_modules"),
      path.join(projectRoot, "node_modules")
    ]
  },

  resolve: {
    extensions: [".ts", ".js", "jsx", ".tsx", ".json"],
    alias: {
      app: path.join(projectRoot, "./src/app.js"),
      "@": path.join(projectRoot, "./src")
    },
    mainFiles: ["index"],
    // modules: ["node_modules"],
    modules: [
      path.resolve(__dirname, "../../node_modules"),
      path.join(projectRoot, "node_modules")
    ]
  },

  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: [
          path.join(projectRoot, "node_modules"),
          path.resolve(__dirname, "../../node_modules")
        ],
        use: [
          {
            loader: "babel-loader",
            options: {
              cacheDirectory: true,
              compact: false
            }
          }
        ]
      },
      {
        test: /\.(j|t)sx?$/,
        use: [
          {
            loader: "babel-loader"
          }
        ],
        exclude: [
          path.join(projectRoot, "node_modules"),
          path.resolve(__dirname, "../../node_modules")
        ]
        // exclude: path.resolve(__dirname, "../../node_modules")
      },
      {
        test: /\.(png|svg|jpg|gif)$/,
        use: [
          {
            loader: "url-loader",
            options: {
              limit: 10000,
              name: "static/img/[name].[hash:7].[ext]"
            }
          }
        ]
      },
      {
        test: /\.(woff|woff2|eot|ttf|otf)$/,
        use: [
          {
            loader: "url-loader",
            options: {
              limit: 10000,
              name: "static/fonts/[name].[hash:7].[ext]"
            }
          }
        ]
      },
      {
        test: /\.(mp4|webm|ogg|mp3|wav|flac|aac)(\?.*)?$/,
        use: [
          {
            loader: "url-loader",
            options: {
              limit: 10000,
              name: "static/media/[name].[hash:7].[ext]"
            }
          }
        ]
      }
    ]
  },

  plugins: [
    // new MiniCssExtractPlugin({
    //   filename: "[name]_[contenthash:8].css"
    // }),
    new CleanWebpackPlugin(),
    new HtmlWebpackPlugin({
      filename: "index.html",
      template: path.join(projectRoot, "index.html")
      // inject: true,
    }),
    new CopyWebpackPlugin([
      {
        from: path.join(projectRoot, "./static"),
        to: "static",
        ignore: [".*"]
      }
    ])
  ]
  //   function errorPlugin() {
  //     this.hooks.done.tap('done', (stats) => {
  //       if (stats.compilation.errors && stats.compilation.errors.length && process.argv.indexOf('--watch') === -1) {
  //         process.exit(1);
  //       }
  //     });
  //   },
  // ].concat(htmlWebpackPlugins)
};
